@@ -5,17 +5,6 @@ import logging
 log = logging.getLogger(__name__)
 
 scaling = 32000.0  # out of 2**15
-SATURATION_THRESHOLD = (2**15 - 1) / scaling
-
-
-class SaturationError(ValueError):
-    pass
-
-
-def check_saturation(x):
-    peak = np.max(np.abs(x))
-    if peak >= SATURATION_THRESHOLD:
-        raise SaturationError(peak)
 
 
 def load(fileobj):
@@ -33,7 +22,7 @@ def dumps(sym):
     return sym.astype('int16').tostring()
 
 
-def iterate(data, size, func=None, truncate=True, enumerate=False):
+def iterate(data, size, func=None, truncate=True, index=False):
     offset = 0
     data = iter(data)
 
@@ -46,7 +35,7 @@ def iterate(data, size, func=None, truncate=True, enumerate=False):
             done = True
 
         result = func(buf) if func else np.array(buf)
-        yield (offset, result) if enumerate else result
+        yield (offset, result) if index else result
         offset += size
 
 
