@@ -1,6 +1,4 @@
-''' Reed-Solomon CODEC. '''
 from . import common
-import bitarray
 
 import functools
 import itertools
@@ -9,7 +7,7 @@ import struct
 import logging
 log = logging.getLogger(__name__)
 
-_crc32 = lambda x, mask: binascii.crc32(x) & mask
+_crc32 = lambda x, mask: binascii.crc32(bytes(x)) & mask
 # (so the result will be unsigned on Python 2/3)
 
 
@@ -23,7 +21,7 @@ class Checksum(object):
         return struct.pack(self.fmt, checksum) + payload
 
     def decode(self, data):
-        received, = struct.unpack(self.fmt, data[:self.size])
+        received, = struct.unpack(self.fmt, bytes(data[:self.size]))
         payload = data[self.size:]
         expected = self.func(payload)
         if received != expected:
@@ -33,8 +31,8 @@ class Checksum(object):
 
 
 class Framer(object):
-    block_size = 1024
-    prefix_fmt = '>L'
+    block_size = 250
+    prefix_fmt = '>B'
     prefix_len = struct.calcsize(prefix_fmt)
     checksum = Checksum()
 
@@ -42,7 +40,7 @@ class Framer(object):
 
     def _pack(self, block):
         frame = self.checksum.encode(block)
-        return struct.pack(self.prefix_fmt, len(frame)) + frame
+        return bytearray(struct.pack(self.prefix_fmt, len(frame)) + frame)
 
     def encode(self, data):
         for block in common.iterate(data=data, size=self.block_size,
@@ -67,7 +65,7 @@ class Framer(object):
         chunk = bytearray(itertools.islice(data, length))
         if len(chunk) < length:
             raise ValueError('missing prefix data')
-        return struct.unpack(fmt, chunk)
+        return struct.unpack(fmt, bytes(chunk))
 
     def _take_len(self, data, length):
         chunk = bytearray(itertools.islice(data, length))
@@ -84,20 +82,34 @@ def chain_wrapper(func):
     return wrapped
 
 
+class BitPacker(object):
+    byte_size = 8
+
+    def __init__(self):
+        bits_list = []
+        for index in range(2 ** self.byte_size):
+            bits = [index & (2 ** k) for k in range(self.byte_size)]
+            bits_list.append(tuple((1 if b else 0) for b in bits))
+
+        self.to_bits = dict((i, bits) for i, bits in enumerate(bits_list))
+        self.to_byte = dict((bits, i) for i, bits in enumerate(bits_list))
+
+
 @chain_wrapper
 def encode(data, framer=None):
+    converter = BitPacker()
     framer = framer or Framer()
     for frame in framer.encode(data):
-        bits = bitarray.bitarray(endian='little')
-        bits.frombytes(bytes(frame))
-        yield bits
+        for byte in frame:
+            yield converter.to_bits[byte]
 
 
 @chain_wrapper
-def _to_bytes(bits, block_size=1):
-    for chunk in common.iterate(data=bits, size=8*block_size,
-                                func=lambda x: x, truncate=True):
-        yield bitarray.bitarray(chunk, endian='little').tobytes()
+def _to_bytes(bits):
+    converter = BitPacker()
+    for chunk in common.iterate(data=bits, size=8,
+                                func=tuple, truncate=True):
+        yield [converter.to_byte[chunk]]
 
 
 @chain_wrapper
