@@ -1,21 +1,17 @@
 import time
-import logging
-
-log = logging.getLogger(__name__)
 
 
 class Reader(object):
 
-    def __init__(self, fd, data_type=None, bufsize=4096,
-                 eof=False, timeout=2.0, wait=0.2):
+    wait = 0.2
+    timeout = 2.0
+    bufsize = 4096
+
+    def __init__(self, fd, data_type=None, eof=False):
         self.fd = fd
         self.data_type = data_type if (data_type is not None) else lambda x: x
-        self.bufsize = bufsize
         self.eof = eof
-        self.timeout = timeout
-        self.wait = wait
         self.total = 0
-        self.check = None
 
     def __iter__(self):
         return self
@@ -40,10 +36,7 @@ class Reader(object):
                 block.extend(data)
 
             if len(block) == self.bufsize:
-                values = self.data_type(block)
-                if self.check:
-                    self.check(values)
-                return values
+                return self.data_type(block)
 
             time.sleep(self.wait)
 
